@@ -1,4 +1,5 @@
 import math
+import numpy as np
 ##########################Box Operations#############################
 def resize_box(box,size):
     cx,cy,w,h=ltrb_to_ccwh(box)
@@ -41,7 +42,13 @@ def rotate_points(points,angle,cx,cy,h,w):
     points=M.dot((points-np.array([cx,cy])).T).T+np.array([nw//2,nh//2])
     points=points.reshape(original_shape)
     return points
-
+def bounding_rect(points):
+    points=np.array(points)
+    l=np.min(points[:,0])
+    r=np.max(points[:,0])
+    t=np.min(points[:,1])
+    b=np.max(points[:,1])
+    return np.array([l,t,r,b])
 def rotate_boxes(boxes,angle,cx,cy,h,w):
     '''原创'''
     boxes=[list(box) for box in boxes]
